@@ -1,7 +1,6 @@
 from .gcsutils.transparentpath import TransparentPath
 from .gcsutils.transparentpath import TransparentPath as Path
-from .gcsutils.transparentpath import TPImportError, TPTypeError, TPValueError, TPAttributeError, TPEnvironmentError,\
-    TPIsADirectoryError, TPNotADirectoryError, TPFileNotFoundError, TPFileExistsError, TPMultipleExistenceError
+from .gcsutils.transparentpath import TPMultipleExistenceError
 
 
 try:
@@ -13,3 +12,8 @@ except ImportError:
                 "Support for json does not seem to be installed for TransparentPath.\n"
                 "You can change that by running 'pip install transparentpath[json]'."
             )
+
+try:
+    from ._version import __version__
+except ImportError:
+    pass
